@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2015-11-19'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -412,7 +412,7 @@ sub _gen_items {
 
     push @permute, "participant", [map {$_->{seq}} @$participants];
 
-    if ($datasets) {
+    if ($datasets && @$datasets) {
         push @permute, "dataset", [map {$_->{seq}} @$datasets];
     }
     $log->debugf("permute: %s", \@permute);
@@ -542,9 +542,9 @@ sub _gen_items {
                     $template_vars = $ds->{args};
                 } elsif ($ds->{argv}) {
                     $template_vars = { map {$_=>$ds->{argv}[$_]}
-                                           @{ $ds->{argv} } };
+                                           0..$#{ $ds->{argv} } };
                 } else {
-                    warn "Item #$i: participant specifies code_template/fcall_template but there is no args/argv in the dataset #$h->{dataset}\n";
+                    #warn "Item #$i: participant specifies code_template/fcall_template but there is no args/argv in the dataset #$h->{dataset}\n";
                 }
 
                 if ($template_vars) {
@@ -1424,7 +1424,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.13 of Bencher (from Perl distribution Bencher), released on 2015-11-19.
+This document describes version 0.14 of Bencher (from Perl distribution Bencher), released on 2015-11-29.
 
 =head1 SYNOPSIS
 
